############################################################
Summarizing data for resources in a report
############################################################

.. autofunction:: wrap_technote.scripts.summaries_run

.. autofunction:: wrap_technote.scripts.create_static_summaries_page

.. autofunction:: wrap_technote.scripts.make_summaries_for_report

.. autofunction:: wrap_technote.scripts.make_summaries_for_resource

.. autofunction:: wrap_technote.scripts.make_wl_summaries

.. autofunction:: wrap_technote.scripts.make_tds_summaries

